@@ -1,5 +1,5 @@
 package Data::TableReader::Decoder::XLS;
-$Data::TableReader::Decoder::XLS::VERSION = '0.001';
+$Data::TableReader::Decoder::XLS::VERSION = '0.002';
 use Moo 2;
 use Carp;
 extends 'Data::TableReader::Decoder::Spreadsheet';
@@ -36,13 +36,12 @@ Data::TableReader::Decoder::XLS - Access sheets/rows of a Microsoft Excel '97 sp
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
 See L<Data::TableReader::Decoder::Spreadsheet>.
-This subclass simply initializes the parser with an instance of
-L<Spreadsheet::ParseExcel>.
+This subclass simply parses the input using an instance of L<Spreadsheet::ParseExcel>.
 
 =head1 AUTHOR
 
