@@ -1,10 +1,10 @@
 package Data::TableReader::Decoder::XLSX;
-$Data::TableReader::Decoder::XLSX::VERSION = '0.001';
+$Data::TableReader::Decoder::XLSX::VERSION = '0.002';
 use Moo 2;
 use Carp;
 extends 'Data::TableReader::Decoder::Spreadsheet';
 
-# ABSTRACT: Access sheets/rows of a Microsoft Excel 2003+ spreadsheet
+# ABSTRACT: Access sheets/rows of a modern XML-based Microsoft Excel spreadsheet
 
 
 sub _build_workbook {
@@ -32,17 +32,16 @@ __END__
 
 =head1 NAME
 
-Data::TableReader::Decoder::XLSX - Access sheets/rows of a Microsoft Excel 2003+ spreadsheet
+Data::TableReader::Decoder::XLSX - Access sheets/rows of a modern XML-based Microsoft Excel spreadsheet
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
 See L<Data::TableReader::Decoder::Spreadsheet>.
-This subclass simply initializes the parser with an instance of
-L<Spreadsheet::ParseXLSX>.
+This subclass simply parses the input using an instance of L<Spreadsheet::ParseXLSX>.
 
 =head1 AUTHOR
 
