@@ -1,5 +1,5 @@
 package Data::TableReader::Iterator;
-$Data::TableReader::Iterator::VERSION = '0.001';
+$Data::TableReader::Iterator::VERSION = '0.002';
 use strict;
 use warnings;
 use Try::Tiny;
@@ -26,6 +26,18 @@ sub DESTROY {
 	delete $_iterator_fields{refaddr shift};
 }
 
+sub progress {
+	undef;
+}
+
+sub tell {
+	undef;
+}
+
+sub seek {
+	undef;
+}
+
 sub next_dataset {
 	undef;
 }
@@ -44,7 +56,7 @@ Data::TableReader::Iterator - Base class for iterators (blessed coderefs)
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -69,6 +81,9 @@ version 0.001
 This is the abstract base class for iterators used in Data::TableReader,
 which are blessed coderefs that return records on each call.
 
+The coderef should support a single argument of a "slice" to extract from the record, in case
+not all of the record is needed.
+
 =head1 ATTRIBUTES
 
 =head2 position
